![Documentation](https://github.com/krishols/designer/actions/workflows/docs.yml/badge.svg)
# Designer
### An evidence-based and student friendly visual graphics library to learn computer science with Python.
